#################################################################################################
###############       INSTITUTO NACIONAL DE ESTADISTICA Y CENSOS - INEC           ###############
###############              DIRECCION DE ESTADISTICAS ECONOMICAS                 ###############
###############          DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS - DIEE         ###############
###############                                                                   ###############
############### TABULADOS DEL DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS, AÑO 2018 ###############                          ###############
#################################################################################################
#Elaborada 25-10-2019.

#Requerimientos##################################################################################
#Es necesario crear un proyecto dentro del mismo deberan estar los siguientes archivos:
#FORMATO SPSS: BASES DE DATOS PUBLICADAS: "DIEE_EMPRESAS_2018_periodo2006_2011"
#                                         "DIEE_EMPRESAS_2018_periodo2012_2018"
#FORMATO EXCEL: CATÁLOGO : "diee_catalogo"
#               PLANTILLA EN BLANCO: "Tabulados_DIEE_2018"
#FORMATO R : SCRIPT_TABULADOS_DIEE_2018
#################################################################################################

#librerias y paquetes#
library(dplyr)
library(openxlsx)
library(reshape2)
library(foreign)
library(data.table)
library(writexl)
install.packages("zipR")

####################################### BASE DE DATOS ##########################################
#Aumentar la capacidad de almacenamiento
memory.limit(size=56000)
#Lectura de la base de datos.
######BASE DE DATOS 2012_2018###################
bd_diee <- read.spss("DIEE_EMPRESAS_2018_periodo2012_2018.sav",use.value.labels=F,to.data.frame = T)
######BASE DE DATOS 2006_2011
bd_diee1 <- read.spss("DIEE_EMPRESAS_2018_periodo2006_2011.sav",use.value.labels=F,to.data.frame = T)

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2018 & situacion==1 )

###########Formato / color####################
newStyle <- createStyle(fgFill = "#FFFFFF") #blanco
grisStyle <- createStyle(fgFill = "#D9D9D9") #gris

####################################### FUNCIONES ##############################################

#########SECCIÓN I: número de empresas##################

################TABULADO 1###############################
###EMPRESAS SEGÚN PARTICIPACIÓN NACIONAL,             ###
###AÑO 2018 POR ESTRUCTURA PARA ESTRATIFICACION       ###

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_estrato <- bd_dieeact %>% group_by(estructura_estrat) %>% summarise("total_estrato"=n(),porcentaje = 0)
total <- as.numeric(sum(t_estrato$total_estrato,na.rm =T ))
t_estrato$porcentaje <- t_estrato$total_estrato / total

#Lectura catalogo de variables.
des_estrato <- read.xlsx("diee_catologo.xlsx", sheet = "estructura_estratificacion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_estrato,t_estrato,by.x = "CODIGO",by.y = "estructura_estrat",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_estrato,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb1<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb1,sheet = "1","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb1,sheet = "1",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb1,sheet = "1",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb1,sheet = "1",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb1,"1",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb1,"1",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado1 <- saveWorkbook(wb1,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 2 ##################################
###TOTAL EMPRESAS (UNIVERSO DIEE), PERIODO 2012 - 2018 POR ANO###	

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee %>% filter(situacion==1 )
#Total empresas del anio 2012-2018
total_anios <- bd_dieeact %>% group_by(anio) %>% summarise("total_anios"=n())

#Exportar resultados a excel
wb2<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb2,sheet = "2",total_anios, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb2,"2",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb2,"2",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado2 <- saveWorkbook(wb2,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#####################TABULADO 3###################################
#EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018#
#               POR FORMA INSTITUCIONAL 	                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieefi <- df1 %>% filter(anio == 2018 & situacion==1 )

#calculo de las variables
t_formainstitucional <- bd_dieefi %>% group_by(forma_institucional) %>% summarise("total_formainstitucional"=n(),porcentaje = 0)
total <- sum(t_formainstitucional$total_formainstitucional,na.rm =T )
t_formainstitucional$porcentaje <- t_formainstitucional$total_formainstitucional / total

#Lectura catalogo de variables.
des_formainstitucional <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_formainstitucional,t_formainstitucional,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_formainstitucional,porcentaje)
t_estrato2 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb3<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb3,sheet = "3","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb3,sheet = "3",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb3,sheet = "3",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb3,sheet = "3",t_estrato2,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb3,"3",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3,"3",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3 <- saveWorkbook(wb3,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 4#################################
#EMPRESAS SEGUNN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018##
#                    POR TAMANO DE EMPRESA                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanop_plazas,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_tamano <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise("total_tamano"=n(),porcentaje = 0)
total <- sum(t_tamano$total_tamano,na.rm =T )
t_tamano$porcentaje <- t_tamano$total_tamano / total

#Lectura catalogo de variables.
des_tamano <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamano,t_tamano,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_tamano,porcentaje)
t_estrato3 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb4<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb4,sheet = "4","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb4,sheet = "4",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb4,sheet = "4",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb4,sheet = "4",t_estrato3,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb4,"4",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"4",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"4",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado4 <- saveWorkbook(wb4,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 5#################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018 #
#                    POR SECTOR ECONOMICO                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_sectores <- bd_dieeact %>% group_by(gsectores) %>% summarise("total_sectores"=n(),porcentaje = 0)
total <- sum(t_sectores$total_sectores,na.rm =T )
t_sectores$porcentaje <- t_sectores$total_sectores / total

#Lectura catalogo de variables.
des_sectores <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectores,t_sectores,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_sectores,porcentaje)
t_estrato4 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb5<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb5,sheet = "5","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb5,sheet = "5",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb5,sheet = "5",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb5,sheet = "5",t_estrato4,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb5,"5",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb5,"5",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado5 <- saveWorkbook(wb5,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 6#################################
#  EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018#
#                POR ACTIVIDAD ECONOMICA                           #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_seccion <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise("total_seccion"=n(),porcentaje = 0)
total <- sum(t_seccion$total_seccion,na.rm =T )
t_seccion$porcentaje <- t_seccion$total_seccion / total

#Lectura catalogo de variables.
des_seccion <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccion,t_seccion,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_seccion,porcentaje)
t_estrato5 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb6<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb6,sheet = "6","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb6,sheet = "6",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb6,sheet = "6",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb6,sheet = "6",t_estrato5,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb6,"6",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb6,"6",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado6 <- saveWorkbook(wb6,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 7################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018#
#                     POR PROVINCIA                               #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_provincia <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise("total_provincia"=n(),porcentaje = 0)
total <- sum(t_provincia$total_provincia,na.rm =T )
t_provincia$porcentaje <- t_provincia$total_provincia / total

##lectura de excel para llenar###
des_provincia <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provincia,t_provincia,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_provincia,porcentaje)
t_estrato6 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb7<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb7,sheet = "7","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb7,sheet = "7",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb7,sheet = "7",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb7,sheet = "7",t_estrato6,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb7,"7",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7,"7",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7 <- saveWorkbook(wb7,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########SECCIÓN II: ventas##################

###################TABULADO 8###############################
#      VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2018 #
#                   POR ANIO                               #

# Lectura de base 2009-2011
bd_dieeventas <- bd_diee1 %>% select(ventas_totales,anio,situacion)
d_dieeven <- bd_dieeventas %>% filter (anio != 2006 & anio != 2007 & anio != 2008)

#Total empresas del año 2012-2018#
t_ventas1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb8<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb8,sheet = "8",t_ventas1, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado8 <- saveWorkbook(wb8,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#Lectura de la base de datos 2012-2018
bd_diee2 <- bd_diee %>% select(ventas_totales,anio,situacion)
bd_dieeac2 <- bd_diee2 %>% filter (situacion == 1)

#Total empresas del año 2012-2018
t_ventas2 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb81<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb81,sheet = "8",t_ventas2, startCol = 1,startRow = 10,colNames = F) ##escribir
addStyle(wb81,"8",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb81,"8",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado8.1 <- saveWorkbook(wb81,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###############TABULADO 9 (CONSTANTES)#########################
###VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2018 POR ANIO

#lectura de base 2009
bd_dieeventas3 <- bd_diee1 %>% select(ventas_totales,anio,situacion)
d_dieeven3 <- bd_dieeventas3 %>% filter (anio == 2009 )
t_ventas2009 <- d_dieeven3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/114.593630834947)*100,na.rm=T))
#Exportar resultados a excel
wb9<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb9,sheet = "9",t_ventas2009, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado9 <- saveWorkbook(wb9,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2010
bd_dieeventas4 <- bd_diee1 %>% select(ventas_totales,anio,situacion)
d_dieeven4 <- bd_dieeventas4 %>% filter (anio == 2010 & situacion == 1)
t_ventas2010 <- d_dieeven4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/123.148137016917)*100,na.rm=T))

#Exportar resultados a excel
wb91<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb91,sheet = "9",t_ventas2010, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado91 <- saveWorkbook(wb91,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2011
bd_dieeventas5 <- bd_diee1 %>% select(ventas_totales,anio,situacion)
d_dieeven5 <- bd_dieeventas5 %>% filter (anio == 2011 & situacion == 1)
t_ventas2011 <- d_dieeven5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb92<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb92,sheet = "9",t_ventas2011, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado92 <- saveWorkbook(wb92,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeventas6 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven6 <- bd_dieeventas6 %>% filter (anio == 2012 & situacion == 1)
t_ventas2012 <- d_dieeven6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb93<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb93,sheet = "9",t_ventas2012, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado93 <- saveWorkbook(wb93,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeventas7 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven7 <- bd_dieeventas7 %>% filter (anio == 2013 & situacion == 1)
t_ventas2013 <- d_dieeven7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb94<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb94,sheet = "9",t_ventas2013, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado94 <- saveWorkbook(wb94,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeventas8 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven8 <- bd_dieeventas8 %>% filter (anio == 2014 & situacion == 1)
t_ventas2014 <- d_dieeven8 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb95<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb95,sheet = "9",t_ventas2014, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado95 <- saveWorkbook(wb95,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeventas9 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven9 <- bd_dieeventas9 %>% filter (anio == 2015 & situacion == 1)
t_ventas2015 <- d_dieeven9 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb96<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb96,sheet = "9",t_ventas2015, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado96 <- saveWorkbook(wb96,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeventas10 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven10 <- bd_dieeventas10 %>% filter (anio == 2016 & situacion == 1)
t_ventas2016 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb97<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb97,sheet = "9",t_ventas2016, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado97 <- saveWorkbook(wb97,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeventas101 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven10 <- bd_dieeventas101 %>% filter (anio == 2017 & situacion == 1)
t_ventas2017 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb971<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb971,sheet = "9",t_ventas2017, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado97 <- saveWorkbook(wb971,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeventas11 <- bd_diee %>% select(ventas_totales,anio,situacion)
d_dieeven11 <- bd_dieeventas11 %>% filter (anio == 2018 & situacion == 1)
t_ventas2018 <- d_dieeven11 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/150.693419713535)*100,na.rm=T))

#Exportar resultados a excel
wb98<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb98,sheet = "9",t_ventas2018, startCol = 1,startRow = 16,colNames = F) ##escribir
addStyle(wb98,"9",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb98,"9",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado98 <- saveWorkbook(wb98,"Tabulados_DIEE_2018.xlsx",overwrite = T)

######################TABULADO 10##################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#              ANIO 2018 POR FORMA INSTITUCIONAL                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

# Calculo de las variables.
t_participacion <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_participacion$total_ventas,na.rm =T )
t_participacion$porcentaje <- t_participacion$total_ventas / total

#Lectura catalogo de variables.
des_participacion <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_participacion,t_participacion,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb10<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb10,sheet = "10","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb10,sheet = "10",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb10,sheet = "10",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb10,sheet = "10",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb10,"10",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb10,"10",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado10 <- saveWorkbook(wb10,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#############################TABULADO 11#########################################
#   VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2018   #
#                        POR TAMANO DE EMPRESA                                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanop_plazas,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_tamanoventas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoventas$total_ventas,na.rm =T )
t_tamanoventas$porcentaje <- t_tamanoventas$total_ventas / total

#Lectura catalogo de variables.
des_tamanoventas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoventas,t_tamanoventas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb11<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb11,sheet = "11","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb11,sheet = "11",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb11,sheet = "11",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb11,sheet = "11",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb11,"11",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb11,"11",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado11 <- saveWorkbook(wb11,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#####################TABULADO 12####################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#            ANIO 2018 POR SECTOR ECONOMICO                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_sectorventas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectorventas$total_ventas,na.rm =T )
t_sectorventas$porcentaje <- t_sectorventas$total_ventas / total

#Lectura catalogo de variables.
des_sectorventas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorventas,t_sectorventas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb12<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb12,sheet = "12","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb12,sheet = "12",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb12,sheet = "12",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb12,sheet = "12",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb12,"12",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb12,"12",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado12 <- saveWorkbook(wb12,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###################TABULADO 13###################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),#
#       ANIO 2018 POR ACTIVIDAD ECONOMICA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_seccventas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb13<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb13,sheet = "13","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb13,sheet = "13",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb13,sheet = "13",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb13,sheet = "13",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb13,"13",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb13,"13",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado13 <- saveWorkbook(wb13,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 14###############################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),#
#          ANIO 2018 POR PROVINCIA                           #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_provventas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provventas$total_ventas,na.rm =T )
t_provventas$porcentaje <- t_provventas$total_ventas / total

#Lectura catalogo de variables.
des_provventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provventas,t_provventas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb14<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb14,sheet = "14","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb14,sheet = "14",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb14,sheet = "14",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb14,sheet = "14",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb14,"14",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb14,"14",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado14 <- saveWorkbook(wb14,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########SECCION III: plazas de empleo registrado, empleo registrado y masa salarial##################

###############TABULADO 15####################################
#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006-2018#

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006 - 2011 POR ANIO
d_plazas <- bd_diee1 %>% select(plazas,plazas_hombres,plazas_mujeres,anio,situacion)

#total empresas del año 2006-2011#
t_plazas <- d_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                  "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                  "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb15<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb15,sheet = "15",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb15,"15",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb15,"15",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado15 <- saveWorkbook(wb15,"Tabulados_DIEE_2018.xlsx",overwrite = T)

########PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2018 POR ANIO

bd_plazas <- bd_diee %>% select(plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas1 <- bd_plazas %>% filter (situacion ==1)

#total empresas del año 2012-2018#
t_plazas <- bd_plazas1 %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                     "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                     "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb151<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb151,sheet = "15",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb151,"15",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb151,"15",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado151 <- saveWorkbook(wb151,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#######################TABULADO 16#############################################
#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), ANIO 2018 POR FORMA INSTITUCIONAL#

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2018 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_plazas <- bd_dieeact %>% select(plazas,forma_institucional,situacion)

#Calculo de las variables.
t_plazasins <- bd_plazas %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb16<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb16,sheet = "16","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb16,sheet = "16",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb16,sheet = "16",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb16,sheet = "16",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb16,"16",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb16,"16",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado16 <- saveWorkbook(wb16,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##############################TABULADO 17##############################################
##PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2018 POR TAMANO DE EMPRESA#

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanop_plazas,plazas,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_tamanoplazas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoplazas$total_plazas,na.rm =T )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_plazas / total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb17<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb17,sheet = "17","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb17,sheet = "17",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb17,sheet = "17",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb17,sheet = "17",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb17,"17",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb17,"17",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb17,"17",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado17 <- saveWorkbook(wb17,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###########################TABULADO 18###############################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2018 POR SECTOR ECONOMICO#

#seleccion de variables###
df1 <- bd_diee %>% select(gsectores,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_sectorplazas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_sectorplazas$total_plazas,na.rm =T )
t_sectorplazas$porcentaje <- t_sectorplazas$total_plazas / total

#Lectura catalogo de variables.
des_sectorplazas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorplazas,t_sectorplazas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb18<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb18,sheet = "18","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb18,sheet = "18",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb18,sheet = "18",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb18,sheet = "18",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb18,"18",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb18,"18",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado18 <- saveWorkbook(wb18,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###########################TABULADO 19##############################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#            ANIO 2018 POR ACTIVIDAD ECONOMICA                     #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#calculo#
t_seccplazas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_seccplazas$total_plazas,na.rm =T )
t_seccplazas$porcentaje <- t_seccplazas$total_plazas / total

#Lectura catalogo de variables.
des_seccplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccplazas,t_seccplazas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb19<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb19,sheet = "19","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb19,sheet = "19",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb19,sheet = "19",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb19,sheet = "19",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb19,"19",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb19,"19",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado19 <- saveWorkbook(wb19,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##############################TABULADO 20############################
#  PERSONAL AFILIADO SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),  #  
#                     ANIO 2018 POR PROVINCIA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,plazas,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_provplazas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_provplazas$total_plazas,na.rm =T )
t_provplazas$porcentaje <- t_provplazas$total_plazas / total

#Lectura catalogo de variables.
des_provplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provplazas,t_provplazas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb20<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb20,sheet = "20","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb20,sheet = "20",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb20,sheet = "20",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb20,sheet = "20",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb20,"20",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb20,"20",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado20 <- saveWorkbook(wb20,"Tabulados_DIEE_2018.xlsx",overwrite = T)

########TABULADO 21##############################################
#PERSONAL AFILIADO (UNIVERSO DIEE), PERIODO 2006 - 2018 POR ANIO#

#BASE GENERAL 2006 - 2011
d_empleo <- bd_diee1 %>% select(empleo,empleo_hombres,empleo_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_empleoafi <- d_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                     "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                     "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb21<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb21,sheet = "21",t_empleoafi, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb21,"21",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb21,"21",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado21 <- saveWorkbook(wb21,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#BASE GENERAL 2012-2018
bd_empleo2 <- bd_diee %>% select(empleo,empleo_hombres,empleo_mujeres,ventas_totales,anio,situacion)
bd_empleo2 <- bd_empleo2 %>% filter (situacion ==1)

#total empresas del anio 2012-2018#
t_empleoafi <- bd_empleo2 %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                    "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                    "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb211<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb211,sheet = "21",t_empleoafi, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb211,"21",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb211,"21",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado211 <- saveWorkbook(wb211,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 22#######################################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2018 POR FORMA INSTITUCIONAL# 

#Filtrar empresas activas del año del cual se requiere
bd_dieeact <- bd_diee%>% filter(anio == 2018 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_empleo <- bd_dieeact %>% select(empleo,forma_institucional,situacion)

#Calculo de las variables.
t_empformains <- bd_empleo %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_empformains$total_empleo,na.rm =T )
t_empformains$porcentaje <- t_empformains$total_empleo / total

#Lectura catalogo de variables.
des_empformainst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empformainst,t_empformains,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb22<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb22,sheet = "22","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb22,sheet = "22",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb22,sheet = "22",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb22,sheet = "22",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb22,"22",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb22,"22",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado22 <- saveWorkbook(wb22,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###########################TABULADO 23#################################################
# PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2018 POR TAMANO DE EMPRESA#

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_empleo,empleo,anio,situacion)
#Seleccion de variables que se requieren para el tabulado.
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanop_empleo) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo / total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanop_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb23<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb23,sheet = "23","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb23,sheet = "23",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb23,sheet = "23",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb23,sheet = "23",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb23,"23",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb23,"23",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb23,"23",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado23 <- saveWorkbook(wb23,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###################################TABULADO 24#######################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2018 POR SECTOR ECONOMICO#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo / total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb24<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb24,sheet = "24","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb24,sheet = "24",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb24,sheet = "24",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb24,sheet = "24",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb24,"24",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb24,"24",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado24 <- saveWorkbook(wb24,"Tabulados_DIEE_2018.xlsx",overwrite = T)

######################TABULADO 25##################################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)# 
#         ANIO 2018 POR ACTIVIDAD ECONOMICA                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_seccempleo <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_seccempleo$total_empleo,na.rm =T )
t_seccempleo$porcentaje <- t_seccempleo$total_empleo / total

#Lectura catalogo de variables.
des_seccempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccempleo,t_seccempleo,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb25<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb25,sheet = "25","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb25,sheet = "25",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb25,sheet = "25",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb25,sheet = "25",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb25,"25",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb25,"25",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado25 <- saveWorkbook(wb25,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########TABULADO 26##########################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2018#
#           POR PROVINCIA                    #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb26<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb26,sheet = "26","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb26,sheet = "26",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb26,sheet = "26",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb26,sheet = "26",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb26,"26",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb26,"26",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado26 <- saveWorkbook(wb26,"Tabulados_DIEE_2018.xlsx",overwrite = T)

################################TABULADO 27##########################################
#       MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2018 POR ANIO                 #

#BASE GENERAL 2006-2011
d_remuneracion <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_remuneraciones <- d_remuneracion %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb27<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb27,sheet = "27",t_remuneraciones, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb27,"27",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb27,"27",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado27 <- saveWorkbook(wb27,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#BASE GENERAL 2012-2018
d_remuneracion <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_remuneracion1 <- d_remuneracion %>% filter(situacion ==1)

#total empresas del año 2012-2018#
t_remuneraciones <- d_remuneracion1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                    "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                    "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb271<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb271,sheet = "27",t_remuneraciones, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb271,"27",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb271,"27",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado271 <- saveWorkbook(wb271,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#################TABULADO 28 : CON#################################
#MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2018 POR ANIO#

#lectura de base 2006
bd_dieems <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems1 <- bd_dieems %>% filter (anio == 2006 & situacion == 1)
t_masa2006 <- d_dieems1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/96.78695716)*100,na.rm=T),
                                                  "total_remuneracioneshombres" =sum((remuneraciones_hombres/96.7869571635269)*100,na.rm=T),
                                                  "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/96.78695716)*100,na.rm=T))
#Exportar resultados a excel
wb28<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb28,sheet = "28",t_masa2006, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado28 <- saveWorkbook(wb28,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2007
bd_dieems1 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems2 <- bd_dieems1 %>% filter (anio == 2007 & situacion == 1)
t_masa2007 <- d_dieems2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/100.0000000)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/100.0000000)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/100.0000000)*100,na.rm=T))
#Exportar resultados a excel
wb281<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb281,sheet = "28",t_masa2007, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado281 <- saveWorkbook(wb281,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2008
bd_dieems2 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems3 <- bd_dieems2 %>% filter (anio == 2008 & situacion == 1)
t_masa2008 <- d_dieems3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/108.83054136472500)*100,na.rm=T))
#Exportar resultados a excel
wb282<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb282,sheet = "28",t_masa2008, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado282 <- saveWorkbook(wb282,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2009
bd_dieems3 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems4 <- bd_dieems3 %>% filter (anio == 2009 & situacion == 1)
t_masa2009 <- d_dieems4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/113.5230353096400)*100,na.rm=T))
#Exportar resultados a excel
wb283<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb283,sheet = "28",t_masa2009, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado283 <- saveWorkbook(wb283,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2010
bd_dieems4 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems5 <- bd_dieems4 %>% filter (anio == 2010 & situacion == 1)
t_masa2010 <- d_dieems5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/117.3011217423320)*100,na.rm=T))
#Exportar resultados a excel
wb284<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb284,sheet = "28",t_masa2010, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado284 <- saveWorkbook(wb284,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2011
bd_dieems5 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems6 <- bd_dieems5 %>% filter (anio == 2011 & situacion == 1)
t_masa2011 <- d_dieems6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb285<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb285,sheet = "28",t_masa2011, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado285 <- saveWorkbook(wb285,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2012
bd_dieems6 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems7 <- bd_dieems6 %>% filter (anio == 2012 & situacion == 1)
t_masa2012 <- d_dieems7 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb286<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb286,sheet = "28",t_masa2012, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado286 <- saveWorkbook(wb286,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2013
bd_dieems7 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems8 <- bd_dieems7 %>% filter (anio == 2013 & situacion == 1)
t_masa2013 <- d_dieems8 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb287<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb287,sheet = "28",t_masa2013, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado287 <- saveWorkbook(wb287,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2014
bd_dieems8 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems9 <- bd_dieems8 %>% filter (anio == 2014 & situacion == 1)
t_masa2014 <- d_dieems9 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb288<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb288,sheet = "28",t_masa2014, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado288 <- saveWorkbook(wb288,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2015
bd_dieems9 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems10 <- bd_dieems9 %>% filter (anio == 2015 & situacion == 1)
t_masa2015 <- d_dieems10 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb289<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb289,sheet = "28",t_masa2015, startCol = 1,startRow = 16,colNames = F) ##escribir
tabulado289 <- saveWorkbook(wb289,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2016
bd_dieems10 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems11 <- bd_dieems10 %>% filter (anio == 2016 & situacion == 1)
t_masa2016 <- d_dieems11 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb2810<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb2810,sheet = "28",t_masa2016, startCol = 1,startRow = 17,colNames = F) ##escribir
tabulado2810 <- saveWorkbook(wb2810,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2018
bd_dieems11 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems12 <- bd_dieems11 %>% filter (anio == 2017 & situacion == 1)
t_masa2017 <- d_dieems12 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb2811<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb2811,sheet = "28",t_masa2017, startCol = 1,startRow = 18,colNames = F) ##escribir
addStyle(wb2811,"28",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb2811,"28",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado2811 <- saveWorkbook(wb2811,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2018
bd_dieems12 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems121 <- bd_dieems12 %>% filter (anio == 2018 & situacion == 1)
t_masa2018 <- d_dieems121 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb2812<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb2812,sheet = "28",t_masa2018, startCol = 1,startRow = 19,colNames = F) ##escribir
addStyle(wb2812,"28",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb2812,"28",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado2811 <- saveWorkbook(wb2812,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#######################TABULADO 29################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#              ANIO 2018 POR FORMA INSTITUCIONAL                 #

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2018 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_remuneraciones <- bd_dieeact %>% select(remuneraciones,forma_institucional,situacion)

#calculo#
t_remuneracionesins <- bd_remuneraciones %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb29<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb29,sheet = "29","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb29,sheet = "29",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb29,sheet = "29",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb29,sheet = "29",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb29,"29",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb29,"29",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado29 <- saveWorkbook(wb29,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##########################TABULADO 30##################################
###   MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) ### 
###              ANIO 2018 POR TAMANO DE EMPRESA                    ###

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_plazas,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 )

#calculo#
t_tamanoremu <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb30<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb30,sheet = "30","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb30,sheet = "30",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb30,sheet = "30",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb30,sheet = "30",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb30,"30",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb30,"30",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb30,"30",grisStyle,cols= 5:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado30 <- saveWorkbook(wb30,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#############################TABULADO 31#########################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#           ANIO 2018 POR SECTOR ECONOMICO                      #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#calculo#
t_sectorremu<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total
                            
#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb31<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb31,sheet = "31","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb31,sheet = "31",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb31,sheet = "31",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb31,sheet = "31",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb31,"31",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb31,"31",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado31 <- saveWorkbook(wb31,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###########################TABULADO 32############################
##MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),## 
#              ANIO 2018 POR ACTIVIDAD ECONOMICA                 #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_seccremu <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccremu$total_remu,na.rm =T )
t_seccremu$porcentaje <- t_seccremu$total_remu / total

#Lectura catalogo de variables.
des_seccremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccremu,t_seccremu,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb32<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb32,sheet = "32","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb32,sheet = "32",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb32,sheet = "32",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb32,sheet = "32",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb32,"32",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb32,"32",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado32 <- saveWorkbook(wb32,"Tabulados_DIEE_2018.xlsx",overwrite = T)

######################TABULADO 33####################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018 POR PROVINCIA#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 )

#Calculo de las variables.
t_provremu <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provremu$total_remu,na.rm =T )
t_provremu$porcentaje <- t_provremu$total_remu / total

#Lectura catalogo de variables.
des_provremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provremu,t_provremu,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb33<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb33,sheet = "33","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb33,sheet = "33",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb33,sheet = "33",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb33,sheet = "33",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb33,"33",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb33,"33",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado33 <- saveWorkbook(wb33,"Tabulados_DIEE_2018.xlsx",overwrite = T)

######EMPRESAS QUE REGISTRAN VENTAS Y EMPLEO DE ACTIVIDADES PRODUCTIVAS (SE EXCLUYE SECCIONES O,P,Q)**#####
#########SECCION IV: número de empresas, ventas, plazas de empleo, empleo registrado y masa salarial##################

###########################TABULADO 34###############################################
#TOTAL EMPRESAS (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2018 POR ANIO#

#BASE GENERAL 2011 
#Seleccion de variables que se requieren para el tabulado.
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
d_act1 <- d_act %>% filter(situacion == 1 & estructura_estrat == 1 & anio== 2011)

#total empresas del año 2006-2011#
t_actprod <- d_act1 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb34<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb34,sheet = "34",t_actprod, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb34,"34",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb34,"34",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado34 <- saveWorkbook(wb34,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#BASE GENERAL 2012-2018
d_act <- bd_diee %>% select(estructura_estrat,codigo_seccion,anio,situacion)
d_act2<- d_act %>% filter(situacion ==1 & estructura_estrat ==1 )

#total empresas del año 2012-2018
t_actprod2 <- d_act2 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb341<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb341,sheet = "34",t_actprod2, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb341,"34",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb341,"34",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado341 <- saveWorkbook(wb341,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##################################TABULADO 35####################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2018 POR FORMA INSTITUCIONAL                                #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,forma_institucional,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_actfi <- bd_dieeact %>% group_by (forma_institucional) %>% summarise ("total_actfi"= n(), porcentaje = 0)
total <- sum(t_actfi$total_actfi,na.rm =T )
t_actfi$porcentaje <- t_actfi$total_actfi / total

#Lectura catalogo de variables.
des_actfi <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_actfi,t_actfi,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_actfi,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb35<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb35,sheet = "35","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb35,sheet = "35",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb35,sheet = "35",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb35,sheet = "35",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb35,"35",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb35,"35",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado35 <- saveWorkbook(wb35,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###############################TABULADO 36#######################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2018 POR TAMANO DE EMPRESAS                          #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,tamanop_plazas,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_tamanoat<- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_at"= n(), porcentaje = 0)
total <- sum(t_tamanoat$total_at,na.rm =T )
t_tamanoat$porcentaje <- t_tamanoat$total_at / total

#Lectura catalogo de variables.
des_tamanoat <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoat,t_tamanoat,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_at,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb36<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb36,sheet = "36","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb36,sheet = "36",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb36,sheet = "36",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb36,sheet = "36",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb36,"36",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb36,"36",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb36,"36",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado36 <- saveWorkbook(wb36,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#################TABULADO 37######################################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#           ANIO 2018 POR SECTOR ECONOMICO                                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_sectorap<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_sectorap$total_ap,na.rm =T )
t_sectorap$porcentaje <- t_sectorap$total_ap / total

#Lectura catalogo de variables.
des_sectorap <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorap,t_sectorap,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb37<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb37,sheet = "37","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb37,sheet = "37",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb37,sheet = "37",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb37,sheet = "37",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb37,"37",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb37,"37",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado37 <- saveWorkbook(wb37,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 38#############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2018, POR ACTIVIDAD ECONOMICA                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccap<- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_seccap$total_ap,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ap / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb38<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb38,sheet = "38","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb38,sheet = "38",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb38,sheet = "38",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb38,sheet = "38",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb38,"38",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb38,"38",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado38 <- saveWorkbook(wb38,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#######################TABULADO 39###############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2018 POR PROVINCIA                                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_provap$total_ap,na.rm =T )
t_provap$porcentaje <- t_provap$total_ap / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb39 <-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb39,sheet = "39","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb39,sheet = "39",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb39,sheet = "39",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb39,sheet = "39",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb39,"39",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb39,"39",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado39 <- saveWorkbook(wb39,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##########################TABULADO 40####################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)  #       
#             PERIODO 2011 - 2018 POR ANIO              #

#Seleccion de variables que se requieren para el tabulado.
##BASE GENERAL 2011###
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion)
d_excact <- d_act %>% filter (estructura_estrat == 1, situacion ==1 , anio ==2011)

#total empresas del año 2006-2011#
t_actprod1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb40<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb40,sheet = "40",t_actprod1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb40,"40",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb40,"40",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado40 <- saveWorkbook(wb40,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##BASE GENERAL 2012-2018###
d_act1 <- bd_diee %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion)
d_excact <- d_act1 %>% filter (estructura_estrat == 1, situacion ==1 )

#total empresas del año 2012-2018#
t_actprod <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb401<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb401,sheet = "40",t_actprod, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb401,"40",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb401,"40",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado401 <- saveWorkbook(wb401,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#####################TABULADO 41 (CONSTANTES)################################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2018##

#lectura de base 2011
bd_dieeap <- bd_diee1 %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap <- bd_dieeap %>% filter (anio == 2011 & situacion == 1&estructura_estrat==1)
t_ventas2011 <- d_dieeap %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb41<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb41,sheet = "41",t_ventas2011, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado41 <- saveWorkbook(wb41,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeap1 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap1 <- bd_dieeap1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat==1)
t_ventas2012 <- d_dieeap1 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb411<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb411,sheet = "41",t_ventas2012, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado411 <- saveWorkbook(wb411,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeap2 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap2 <- bd_dieeap2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat==1)
t_ventas2013 <- d_dieeap2 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb412<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb412,sheet = "41",t_ventas2013, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado412 <- saveWorkbook(wb412,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeap3 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap3 <- bd_dieeap3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat==1)
t_ventas2014 <- d_dieeap3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb413<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb413,sheet = "41",t_ventas2014, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado413 <- saveWorkbook(wb413,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeap4 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap4 <- bd_dieeap4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat==1)
t_ventas2015 <- d_dieeap4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb414<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb414,sheet = "41",t_ventas2015, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado414 <- saveWorkbook(wb414,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeap5 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap5 <- bd_dieeap5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat==1)
t_ventas2016 <- d_dieeap5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb415<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb415,sheet = "41",t_ventas2016, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado415 <- saveWorkbook(wb415,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeap6 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap6 <- bd_dieeap6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat==1)
t_ventas2017 <- d_dieeap6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb416<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb416,sheet = "41",t_ventas2017, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb416,"41",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb416,"41",grisStyle,cols= 1:2, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado416 <- saveWorkbook(wb416,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeap7 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat)
d_dieeap7 <- bd_dieeap7 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat==1)
t_ventas2018 <- d_dieeap7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/150.693419713535)*100,na.rm=T))

#Exportar resultados a excel
wb417<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb417,sheet = "41",t_ventas2018, startCol = 1,startRow = 15,colNames = F) ##escribir
addStyle(wb417,"41",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb417,"41",grisStyle,cols= 1:2, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado416 <- saveWorkbook(wb417,"Tabulados_DIEE_2018.xlsx",overwrite = T)

################################TABULADO 42############################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2018 POR FORMA INSTITUCIONAL                             #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccventas <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb42<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb42,sheet = "42","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb42,sheet = "42",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb42,sheet = "42",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb42,sheet = "42",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb42,"42",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb42,"42",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado42 <- saveWorkbook(wb42,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#################################TABULADO 43###########################################
# VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS#
#                ANIO 2018 POR TAMANO DE  EMPRESA                                     #

#seleccion de variables###
bd_tamano <- bd_diee %>% select(tamanop_plazas,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_tamanovp <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_vp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanovp$total_vp,na.rm =T )
t_tamanovp$porcentaje <- t_tamanovp$total_vp/ total

#Lectura catalogo de variables.
des_tamanovp <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanovp,t_tamanovp,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb43<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb43,sheet = "43","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb43,sheet = "43",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb43,sheet = "43",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb43,sheet = "43",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb43,"43",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb43,"43",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb43,"43",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb43,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##################TABULADO 44##########################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                   ANIO 2018 POR SECTOR ECONOMICO                                    #

#seleccion de variables
bd_tamano <- bd_diee %>% select(gsectores,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_secvp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_secvp,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_secvp/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_secvp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb44<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb44,sheet = "44","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb44,sheet = "44",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb44,sheet = "44",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb44,sheet = "44",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb44,"44",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb44,"44",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb44,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##########################TABULADO 45##################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2018, POR ACTIVIDAD ECONOMICA                            # 

#seleccion de variables###
bd_tamano <- bd_diee %>% select(codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccap <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccap$total_ventas,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ventas / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb45<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb45,sheet = "45","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb45,sheet = "45",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb45,sheet = "45",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb45,sheet = "45",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb45,"45",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb45,"45",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb45,"Tabulados_DIEE_2018.xlsx",overwrite = T)

################################TABULADO 46##########################################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#                ANIO 2018 POR PROVINCIA                                            #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_ventas,na.rm =T )
t_provap$porcentaje <- t_provap$total_ventas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb46 <-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb46,sheet = "46","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb46,sheet = "46",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb46,sheet = "46",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb46,sheet = "46",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb46,"46",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb46,"46",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb46,"Tabulados_DIEE_2018.xlsx",overwrite = T)

########################TABULADO 47#################################
#PLAZAS DE EMPEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #                  
#                   PERIODO 2011 - 2018 POR ANIO                   #

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006-2011

d_plazas <- bd_diee1 %>% select(estructura_estrat,plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2018#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb47<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb47,sheet = "47",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb47,"47",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb47,"47",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb47,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2018 POR ANIO

d_plazas <- bd_diee %>% select(estructura_estrat,plazas,plazas_hombres,plazas_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2018#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_mujeres,na.rm=T))

#Exportar resultados a excel
wb471<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb471,sheet = "47",t_plazas, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb471,"47",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb471,"47",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb471,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################################TABULADO 48#############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL          #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR FORMA INSTITUCIONAL#

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,plazas,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_plazasins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb48<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb48,sheet = "48","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb48,sheet = "48",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb48,sheet = "48",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb48,sheet = "48",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb48,"48",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb48,"48",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb48,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#################################TABULADO 49###############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL         #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR TAMANO DE EMPRESA #

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanop_plazas,plazas,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_tamanoplazas <- bd_dieeact %>% group_by(tamanop_plazas) %>% summarise ("total_vp"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoplazas$total_vp,na.rm =T )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_vp/ total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb49<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb49,sheet = "49","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb49,sheet = "49",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb49,sheet = "49",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb49,sheet = "49",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb49,"49",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb49,"49",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb49,"49",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb49,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#########################TABULADO 50######################################
#       PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL       #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR SECTOR ECONOMICO  #

#seleccion de variables
bd_sector <- bd_diee %>% select(gsectores,plazas,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_sector %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_plazas,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_plazas/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))
v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb50<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb50,sheet = "50","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb50,sheet = "50",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb50,sheet = "50",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb50,sheet = "50",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb50,"50",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb50,"50",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb50,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##############################TABULADO 51##################################
#   PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL            #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR ACTIVIDAD ECONOMICA#

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,plazas,estructura_estrat,anio,situacion)
bd_dieeact <- bd_act %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_plazas,na.rm =T )
t_secact$porcentaje <- t_secact$total_plazas / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb51<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb51,sheet = "51","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb51,sheet = "51",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb51,sheet = "51",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb51,sheet = "51",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb51,"51",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb51,"51",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb51,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 52######################################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION NACIONAL      #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR PROVINCIA   #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,plazas,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_plazas,na.rm =T )
t_provap$porcentaje <- t_provap$total_plazas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb52 <-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb52,sheet = "52","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb52,sheet = "52",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb52,sheet = "52",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb52,sheet = "52",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb52,"52",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb52,"52",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb52,"Tabulados_DIEE_2018.xlsx",overwrite = T)

######################## TABULADO 53 ##########################################
#EMPLEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2018#

# EMPLEO (UNIVERSO DIEE) PERIODO 2006-2011
#Seleccion de variables que se requieren para el tabulado.
d_empleo <- bd_diee1 %>% select(estructura_estrat,empleo,empleo_hombres,empleo_mujeres,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_empleo <- d_empleo %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2018#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb53<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb53,sheet = "53",t_empleo, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb53,"53",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb53,"53",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb53,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2018 POR ANIO

d_empleo <- bd_diee %>% select(estructura_estrat,empleo,empleo_hombres,empleo_mujeres,anio,situacion)
bd_empleo <- d_empleo %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2018#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_mujeres,na.rm=T))

#Exportar resultados a excel
wb531<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb531,sheet = "53",t_empleo, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb531,"53",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb531,"53",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb531,"Tabulados_DIEE_2018.xlsx",overwrite = T)

############TABULADO 54#####################################################
#      EMPLEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL                   #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018 POR FORMA INSTITUCIONAL#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,empleo,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_empleoins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_empleoins$total_empleo,na.rm =T )
t_empleoins$porcentaje <- t_empleoins$total_empleo / total

#Lectura catalogo de variables.
des_empleoinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empleoinst,t_empleoins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb54 <-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb54,sheet = "54","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb54,sheet = "54",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb54,sheet = "54",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb54,sheet = "54",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb54,"54",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb54,"54",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb54,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 55################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2018POR TAMANO DE EMPRESA                                 #

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanop_empleo,empleo,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanop_empleo) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo/ total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanop_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb55<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb55,sheet = "55","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb55,sheet = "55",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb55,sheet = "55",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb55,sheet = "55",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb55,"55",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb55,"55",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb55,"55",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb55,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##############TABULADO 56######################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#            ANIO 2018 POR SECTOR ECONOMICO                                   #     


#seleccion de variables###
bd_sector <- bd_diee %>% select(gsectores,empleo,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_sector %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo/ total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb56<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb56,sheet = "56","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb56,sheet = "56",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb56,sheet = "56",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb56,sheet = "56",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb56,"56",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb56,"56",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb56,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#################TABULADO 57##############################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018#
#                    POR ACTIVIDAD ECONOMICA                                             #

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,empleo,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_act %>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_empleo,na.rm =T )
t_secact$porcentaje <- t_secact$total_empleo / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_secact,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb57<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb57,sheet = "57","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb57,sheet = "57",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb57,sheet = "57",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb57,sheet = "57",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb57,"57",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb57,"57",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb57,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 58#########################################################
##EMPLEO SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018#
#                                POR PROVINCIA                                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,empleo,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2018 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb58 <-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb58,sheet = "58","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb58,sheet = "58",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb58,sheet = "58",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb58,sheet = "58",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb58,"58",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb58,"58",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb58,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 59#############################################
##MASA SALARIAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2018#
#                          POR ANIO                                        #

##BASE GENERAL 2011
d_remuneracion1 <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact1 <- bd_diee1 %>% filter(anio==2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2006-2011
t_remuneraciones1 <- bd_dieeact1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb59<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb59,sheet = "59",t_remuneraciones1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb59,"59",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb59,"59",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb59,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##BASE GENERAL 2012-2018
d_remuneracion <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact <- d_remuneracion %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2018
t_remuneraciones <- bd_dieeact %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb601<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb601,sheet = "59",t_remuneraciones, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb601,"59",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb601,"59",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb601,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 60: CONSTANTE#################
#           MASA SALARIAL CONSTANTE            #

#lectura de base 2011
bd_dieemsc <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc <- bd_dieemsc %>% filter (anio == 2011 & situacion == 1& estructura_estrat ==1)
t_masa2011 <- d_dieemsc %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb602<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb602,sheet = "60",t_masa2011, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado602 <- saveWorkbook(wb602,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2012
bd_dieemsc1 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc1 <- bd_dieemsc1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat ==1)
t_masa2012 <- d_dieemsc1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb603<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb603,sheet = "60",t_masa2012, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado603 <- saveWorkbook(wb603,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2013
bd_dieemsc2 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc2 <- bd_dieemsc2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat ==1)
t_masa2013 <- d_dieemsc2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb604<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb604,sheet = "60",t_masa2013, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado604 <- saveWorkbook(wb604,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2014
bd_dieemsc3 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc3 <- bd_dieemsc3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat ==1)
t_masa2014 <- d_dieemsc3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb605<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb605,sheet = "60",t_masa2014, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado605 <- saveWorkbook(wb605,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2015
bd_dieemsc4 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc4 <- bd_dieemsc4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat ==1)
t_masa2015 <- d_dieemsc4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb606<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb606,sheet = "60",t_masa2015, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado606 <- saveWorkbook(wb606,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2016
bd_dieemsc5 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc5 <- bd_dieemsc5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat ==1)
t_masa2016 <- d_dieemsc5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb607<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb607,sheet = "60",t_masa2016, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado607 <- saveWorkbook(wb607,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2017
bd_dieemsc6 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc6 <- bd_dieemsc6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat ==1)
t_masa2017 <- d_dieemsc6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb608<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb608,sheet = "60",t_masa2017, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb608,"60",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb608,"60",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado608 <- saveWorkbook(wb608,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#lectura de base 2018
bd_dieemsc7 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc7 <- bd_dieemsc7 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat ==1)
t_masa2018 <- d_dieemsc7 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb609<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb609,sheet = "60",t_masa2018, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb609,"60",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb609,"60",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado608 <- saveWorkbook(wb609,"Tabulados_DIEE_2018.xlsx",overwrite = T)

####################TABULADO 61###################################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018#
#               POR FORMA INSTITUCIONAL                                                          #

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,forma_institucional,situacion, estructura_estrat)
bd_dieems <- bd_remuneraciones%>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_remuneracionesins <- bd_dieems %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb61<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb61,sheet = "61","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb61,sheet = "61",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb61,sheet = "61",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb61,sheet = "61",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb61,"61",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb61,"61",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb61,"Tabulados_DIEE_2018.xlsx",overwrite = T)

###################TABULADO 62###################################################################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018#
#             POR TAMANO DE EMPRESA                                                             #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,tamanop_plazas,situacion, estructura_estrat)
bd_dieetam <- bd_diee%>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)
      
#calculo#
t_tamanoremu <- bd_dieetam %>% group_by(tamanop_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanop_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb62<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb62,sheet = "62","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb62,sheet = "62",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb62,sheet = "62",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb62,sheet = "62",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb62,"62",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb62,"62",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb62,"62",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb62,"Tabulados_DIEE_2018.xlsx",overwrite = T)

#######################TABULADO 63################################################################
#"MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2018#
#                   POR SECTOR ECONOMICO                                                         #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,gsectores,situacion, estructura_estrat)
bd_dieese <- bd_diee%>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorremu<- bd_dieese %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total

#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb63<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb63,sheet = "63","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb63,sheet = "63",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb63,sheet = "63",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb63,sheet = "63",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb63,"63",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb63,"63",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb63,"Tabulados_DIEE_2018.xlsx",overwrite = T)

############TABULADO 64####################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2018#
#       POR ACTIVIDAD ECONOMICA                                           #  

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_seccion,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccre <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccre$total_remu,na.rm =T )
t_seccre$porcentaje <- t_seccre$total_remu / total

#Lectura catalogo de variables.
des_seccre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccre,t_seccre,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb64<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb64,sheet = "64","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb64,sheet = "64",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb64,sheet = "64",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb64,sheet = "64",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb64,"64",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb64,"64",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb64,"Tabulados_DIEE_2018.xlsx",overwrite = T)

##########TABULADO 65################################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2018 POR PROVINCIA#

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_provincia,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2018 & situacion==1 & estructura_estrat==1)

#calculo#
t_provre <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provre$total_remu,na.rm =T )
t_provre$porcentaje <- t_provre$total_remu / total
 
#Lectura catalogo de variables.
des_provre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provre,t_provre,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb65<-loadWorkbook(file = "Tabulados_DIEE_2018.xlsx")
writeData(wb65,sheet = "65","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb65,sheet = "65",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb65,sheet = "65",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb65,sheet = "65",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb65,"65",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb65,"65",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb65,"Tabulados_DIEE_2018.xlsx",overwrite = T)
